==> ejc-accplat-impl-3.0.0-20231219.081400-23-sources.jar: com/ejianc/business/accplat/bean/BillInfluenceSetEntity.java <==
package com.ejianc.business.accplat.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 会计平台设置-影响因素关联
 * 
 * @author generator
 * 
 */
 @TableName("ejc_accplat_bill_influence_set")
public class BillInfluenceSetEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_type_id")
    private Long billTypeId; // 单据类型id
    @TableField(value="bill_type_code")
    private String billTypeCode; // 单据类型编码
    @TableField(value="bill_type_name")
    private String billTypeName; // 单据类型
    @TableField(value="influence_id")
    private Long influenceId; // 影响因素id
    @TableField(value="influence_name")
    private String influenceName; // 影响因素name
    @TableField(value="column_view")
    private String columnView; // 字段显示
    @TableField(value="column_expression")
    private String columnExpression; // 字段表达式
    
    
    

    public Long getBillTypeId() {
        return billTypeId;
    }

    public void setBillTypeId(Long billTypeId) {
        this.billTypeId = billTypeId;
    }
    public String getBillTypeCode() {
        return billTypeCode;
    }

    public void setBillTypeCode(String billTypeCode) {
        this.billTypeCode = billTypeCode;
    }
    public String getBillTypeName() {
        return billTypeName;
    }

    public void setBillTypeName(String billTypeName) {
        this.billTypeName = billTypeName;
    }
    public Long getInfluenceId() {
        return influenceId;
    }

    public void setInfluenceId(Long influenceId) {
        this.influenceId = influenceId;
    }
    public String getInfluenceName() {
        return influenceName;
    }

    public void setInfluenceName(String influenceName) {
        this.influenceName = influenceName;
    }
    public String getColumnView() {
        return columnView;
    }

    public void setColumnView(String columnView) {
        this.columnView = columnView;
    }
    public String getColumnExpression() {
        return columnExpression;
    }

    public void setColumnExpression(String columnExpression) {
        this.columnExpression = columnExpression;
    }
    
}

==> ejc-accplat-impl-3.0.0-20231222.030955-46-sources.jar: com/ejianc/business/accplat/bean/BillInfluenceSetEntity.java <==
package com.ejianc.business.accplat.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 会计平台设置-影响因素关联
 * 
 * @author generator
 * 
 */
 @TableName("ejc_accplat_bill_influence_set")
public class BillInfluenceSetEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_type_id")
    private Long billTypeId; // 单据类型id
    @TableField(value="bill_type_code")
    private String billTypeCode; // 单据类型编码
    @TableField(value="bill_type_name")
    private String billTypeName; // 单据类型
    @TableField(value="influence_id")
    private Long influenceId; // 影响因素id
    @TableField(value="influence_name")
    private String influenceName; // 影响因素name
    @TableField(value="column_view")
    private String columnView; // 字段显示
    @TableField(value="column_expression")
    private String columnExpression; // 字段表达式

    @TableField(value="column_id")
    private Long columnId; // 字段id

    @TableField(value="column_name")
    private String columnName; // 字段

    @TableField(value="column_pos")
    private String columnPos;  // 字段位置:H主表、HR主表关联、B子表、BR子表关联

    public String getColumnPos() {
        return columnPos;
    }

    public void setColumnPos(String columnPos) {
        this.columnPos = columnPos;
    }


    public Long getColumnId() {
        return columnId;
    }

    public void setColumnId(Long columnId) {
        this.columnId = columnId;
    }

    public String getColumnName() {
        return columnName;
    }

    public void setColumnName(String columnName) {
        this.columnName = columnName;
    }

    public Long getBillTypeId() {
        return billTypeId;
    }

    public void setBillTypeId(Long billTypeId) {
        this.billTypeId = billTypeId;
    }
    public String getBillTypeCode() {
        return billTypeCode;
    }

    public void setBillTypeCode(String billTypeCode) {
        this.billTypeCode = billTypeCode;
    }
    public String getBillTypeName() {
        return billTypeName;
    }

    public void setBillTypeName(String billTypeName) {
        this.billTypeName = billTypeName;
    }
    public Long getInfluenceId() {
        return influenceId;
    }

    public void setInfluenceId(Long influenceId) {
        this.influenceId = influenceId;
    }
    public String getInfluenceName() {
        return influenceName;
    }

    public void setInfluenceName(String influenceName) {
        this.influenceName = influenceName;
    }
    public String getColumnView() {
        return columnView;
    }

    public void setColumnView(String columnView) {
        this.columnView = columnView;
    }
    public String getColumnExpression() {
        return columnExpression;
    }

    public void setColumnExpression(String columnExpression) {
        this.columnExpression = columnExpression;
    }
    
}
